# Neuroscience 440 Toolkit
This is a toolkit for students taking the quantitative companion course of the neusci 30x series.

The toolkit provides functions and classes for interacting with data obtained in lab periods, spike sorting, filtering, etc.